@@ -39,7 +39,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: annotate.c,v 1.42 2008/10/08 15:47:06 murch Exp $
+ * $Id: annotate.c,v 1.44 2009/02/09 05:08:20 brong Exp $
  */
 
 #include <config.h>
@@ -422,6 +422,19 @@ struct mailbox_annotation_rock
     char *server, *partition, *acl, *path, *mpath;
 };
 
+const struct annotate_info_t annotate_mailbox_flags[] =
+{
+    { "/vendor/cmu/cyrus-imapd/pop3newuidl",
+      OPT_POP3_NEW_UIDL },
+    { "/vendor/cmu/cyrus-imapd/duplicatedeliver",
+      OPT_IMAP_DUPDELIVER },
+    { "/vendor/cmu/cyrus-imapd/sharedseen",
+      OPT_IMAP_SHAREDSEEN },
+    { "/vendor/cmu/cyrus-imapd/condstore",
+      OPT_IMAP_CONDSTORE },
+    { NULL, 0 }
+};
+
 /* To free values in the mailbox_annotation_rock as needed */
 static void cleanup_mbrock(struct mailbox_annotation_rock *mbrock __attribute__((unused))) 
 {
@@ -506,9 +519,9 @@ static void output_entryatt(const char *mboxname, const char *entry,
 			    struct fetchdata *fdata)
 {
     static struct attvaluelist *attvalues = NULL;
-    static char lastname[MAX_MAILBOX_NAME+1];
-    static char lastentry[MAX_MAILBOX_NAME+1];
-    char key[MAX_MAILBOX_PATH+1]; /* XXX MAX_MAILBOX_NAME + entry + userid */
+    static char lastname[MAX_MAILBOX_BUFFER];
+    static char lastentry[MAX_MAILBOX_BUFFER];
+    char key[MAX_MAILBOX_BUFFER]; /* XXX MAX_MAILBOX_NAME + entry + userid */
     char buf[100];
 
     /* We have to reset before each GETANNOTATION command.
@@ -611,7 +624,7 @@ static void annotation_get_fromfile(const char *int_mboxname __attribute__((unus
 				    void *rock)
 {
     const char *filename = (const char *) rock;
-    char path[1024], buf[1024], *p;
+    char path[MAX_MAILBOX_PATH+1], buf[MAX_MAILBOX_PATH+1], *p;
     FILE *f;
     struct stat statbuf;
     struct annotation_data attrib;
@@ -878,7 +891,7 @@ static void annotation_get_mailboxopt(const char *int_mboxname,
 				      void *rock __attribute__((unused)))
 { 
     struct mailbox mailbox;
-    int flag, r = 0;
+    int flag = 0, r = 0, i;
     char value[40];
     struct annotation_data attrib;
   
@@ -891,16 +904,14 @@ static void annotation_get_mailboxopt(const char *int_mboxname,
     /* Make sure its a local mailbox */
     if (mbrock->server) return;
 
-    /* Check entry */
-    if (!strcmp(entry, "/vendor/cmu/cyrus-imapd/condstore")) {
-	flag = OPT_IMAP_CONDSTORE;
-    } else if (!strcmp(entry, "/vendor/cmu/cyrus-imapd/sharedseen")) {
-	flag = OPT_IMAP_SHAREDSEEN;
-    } else if (!strcmp(entry, "/vendor/cmu/cyrus-imapd/duplicatedeliver")) {
-	flag = OPT_IMAP_DUPDELIVER;
-    } else {
-	return;
+    /* check that this is a mailboxopt annotation */
+    for (i = 0; annotate_mailbox_flags[i].name; i++) {
+	if (!strcmp(entry, annotate_mailbox_flags[i].name)) {
+	    flag = annotate_mailbox_flags[i].flag;
+	    break;
+	}
     }
+    if (!flag) return;
   
     /* Check ACL */
     if(!fdata->isadmin &&
@@ -1028,6 +1039,8 @@ const struct annotate_f_entry mailbox_ro_entries[] =
       annotation_get_lastupdate, NULL },
     { "/vendor/cmu/cyrus-imapd/lastpop", BACKEND_ONLY,
       annotation_get_lastpop, NULL },
+    { "/vendor/cmu/cyrus-imapd/pop3newuidl", BACKEND_ONLY,
+      annotation_get_mailboxopt, NULL },
     { "/vendor/cmu/cyrus-imapd/condstore", BACKEND_ONLY,
       annotation_get_mailboxopt, NULL },
     { "/vendor/cmu/cyrus-imapd/sharedseen", BACKEND_ONLY,
@@ -1080,10 +1093,10 @@ static int fetch_cb(char *name, int matchlen,
 {
     struct fetchdata *fdata = (struct fetchdata *) rock;
     struct annotate_f_entry_list *entries_ptr;
-    static char lastname[MAX_MAILBOX_PATH+1];
+    static char lastname[MAX_MAILBOX_BUFFER];
     static int sawuser = 0;
     int c;
-    char int_mboxname[MAX_MAILBOX_PATH+1], ext_mboxname[MAX_MAILBOX_PATH+1];
+    char int_mboxname[MAX_MAILBOX_BUFFER], ext_mboxname[MAX_MAILBOX_BUFFER];
     struct mailbox_annotation_rock mbrock;
 
     /* We have to reset the sawuser flag before each fetch command.
@@ -1298,7 +1311,7 @@ int annotatemore_fetch(char *mailbox,
 	/* mailbox annotation(s) */
 
 	if (fdata.entry_list || proxy_fetch_func) {
-	    char mboxpat[MAX_MAILBOX_NAME+1];
+	    char mboxpat[MAX_MAILBOX_BUFFER];
 
 	    /* Reset state in fetch_cb */
 	    fetch_cb(NULL, 0, 0, 0);
@@ -1537,7 +1550,7 @@ static int store_cb(char *name, int matchlen,
     struct annotate_st_entry_list *entries_ptr;
     static char lastname[MAX_MAILBOX_PATH+1];
     static int sawuser = 0;
-    char int_mboxname[MAX_MAILBOX_PATH+1];
+    char int_mboxname[MAX_MAILBOX_BUFFER];
     struct mailbox_annotation_rock mbrock;
     int r = 0;
 
@@ -1621,7 +1634,7 @@ static int annotation_set_tofile(const char *int_mboxname __attribute__((unused)
 				 void *rock)
 {
     const char *filename = (const char *) rock;
-    char path[1024];
+    char path[MAX_MAILBOX_PATH+1];
     FILE *f;
 
     /* Check ACL */
@@ -1717,20 +1730,16 @@ static int annotation_set_mailboxopt(const char *int_mboxname,
 				     void *rock __attribute__((unused)))
 {
     struct mailbox mailbox;
-    int flag, r = 0;
+    int flag = 0, r = 0, i;
 
     /* Check entry */
-    if (!strcmp(entry->entry->name, "/vendor/cmu/cyrus-imapd/condstore")) {
-	flag = OPT_IMAP_CONDSTORE;
-    } else if (!strcmp(entry->entry->name,
-		       "/vendor/cmu/cyrus-imapd/sharedseen")) {
-	flag = OPT_IMAP_SHAREDSEEN;
-    } else if (!strcmp(entry->entry->name,
-		       "/vendor/cmu/cyrus-imapd/duplicatedeliver")) {
-	flag = OPT_IMAP_DUPDELIVER;
-    } else {
-	return IMAP_PERMISSION_DENIED;
+    for (i = 0; annotate_mailbox_flags[i].name; i++) {
+	if (!strcmp(entry->entry->name, annotate_mailbox_flags[i].name)) {
+	    flag = annotate_mailbox_flags[i].flag;
+	    break;
+	}
     }
+    if (!flag) return IMAP_PERMISSION_DENIED;
   
     /* Check ACL */
     if(!sdata->isadmin &&
@@ -1820,6 +1829,9 @@ const struct annotate_st_entry mailbox_rw_entries[] =
     { "/vendor/cmu/cyrus-imapd/sieve", ATTRIB_TYPE_STRING, BACKEND_ONLY,
       ATTRIB_VALUE_SHARED | ATTRIB_CONTENTTYPE_SHARED,
       ACL_ADMIN, annotation_set_todb, NULL },
+    { "/vendor/cmu/cyrus-imapd/pop3newuidl", ATTRIB_TYPE_BOOLEAN, BACKEND_ONLY,
+      ATTRIB_VALUE_SHARED | ATTRIB_CONTENTTYPE_SHARED,
+      ACL_ADMIN, annotation_set_mailboxopt, NULL },
     { "/vendor/cmu/cyrus-imapd/condstore", ATTRIB_TYPE_BOOLEAN, BACKEND_ONLY,
       ATTRIB_VALUE_SHARED | ATTRIB_CONTENTTYPE_SHARED,
       ACL_ADMIN, annotation_set_mailboxopt, NULL },
@@ -1982,7 +1994,7 @@ int annotatemore_store(char *mailbox,
     else {
 	/* mailbox annotations */
 
-	char mboxpat[MAX_MAILBOX_NAME+1];
+	char mboxpat[MAX_MAILBOX_BUFFER];
 
 	/* Reset state in store_cb */
 	store_cb(NULL, 0, 0, 0);
