@@ -39,7 +39,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: cyr_synclog.c,v 1.2 2008/03/24 17:09:16 murch Exp $
+ * $Id: cyr_synclog.c,v 1.5 2009/02/11 19:11:32 murch Exp $
  *
  * Originally written by Bron Gondwana <brong@fastmail.fm>
  */
@@ -54,6 +54,8 @@
 
 #include "global.h"
 #include "sync_log.h"
+#include "util.h"
+#include "xmalloc.h"
 
 /* config.c stuff */
 const int config_need_data = 0;
@@ -64,6 +66,10 @@ int main(int argc, char *argv[])
     char cmd = '\0';
     char opt;
 
+    if ((geteuid()) == 0 && (become_cyrus() != 0)) {
+	fatal("must run as the Cyrus user", EC_USAGE);
+    }
+
     while ((opt = getopt(argc, argv, "C:uvmacqnsb")) != EOF) {
 	switch (opt) {
 	case 'C': /* alt config file */
@@ -149,7 +155,7 @@ int main(int argc, char *argv[])
 	    sync_log_seen(argv[optind], argv[optind+1]);
 	    break;
 	case 'b': /* suBscription */
-	    sync_log_subscribe(argv[optind], argv[optind+1], argv[optind+2]);
+	    sync_log_subscribe(argv[optind], argv[optind+1]);
 	    break;
         default:
             /* just as is! */
