@@ -39,7 +39,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: mboxlist.c,v 1.260 2008/10/08 15:47:08 murch Exp $
+ * $Id: mboxlist.c,v 1.263 2009/02/09 05:04:38 brong Exp $
  */
 
 #include <config.h>
@@ -239,7 +239,7 @@ static int mboxlist_mylookup(const char *name, int *typep,
 	break;
 
     default:
-	syslog(LOG_ERR, "DBERROR: error fetching %s: %s",
+	syslog(LOG_ERR, "DBERROR: error fetching mboxlist %s: %s",
 	       name, cyrusdb_strerror(r));
 	return IMAP_IOERROR;
 	break;
@@ -362,7 +362,7 @@ mboxlist_mycreatemailboxcheck(char *name,
     char *p;
     char *acl;
     char *defaultacl, *identifier, *rights;
-    char parent[MAX_MAILBOX_NAME+1];
+    char parent[MAX_MAILBOX_BUFFER];
     unsigned long parentlen;
     char *parentname = NULL;
     char *parentpartition = NULL;
@@ -885,7 +885,7 @@ mboxlist_delayed_deletemailbox(const char *name, int isadmin, char *userid,
                                int local_only __attribute__((unused)),
 			       int force)
 {
-    char newname[MAX_MAILBOX_PATH+1];
+    char newname[MAX_MAILBOX_BUFFER];
     char *path, *mpath;
     char *acl;
     char *partition;
@@ -1925,7 +1925,7 @@ static int find_p(void *rockp,
 
     minmatch = 0;
     if (rock->inboxoffset) {
-	char namebuf[MAX_MAILBOX_NAME+1];
+	char namebuf[MAX_MAILBOX_BUFFER];
 
 	if(keylen >= (int) sizeof(namebuf)) {
 	    syslog(LOG_ERR, "oversize keylen in mboxlist.c:find_p()");
@@ -1971,7 +1971,7 @@ static int find_p(void *rockp,
 
     /* Suppress deleted hierarchy unless admin: overrides ACL_LOOKUP test */
     if (!rock->isadmin) {
-	char namebuf[MAX_MAILBOX_NAME+1];
+	char namebuf[MAX_MAILBOX_BUFFER];
 
 	memcpy(namebuf, key, keylen);
 	namebuf[keylen] = '\0';
@@ -2026,7 +2026,7 @@ static int find_cb(void *rockp,
 		   const char *data __attribute__((unused)),
 		   int datalen __attribute__((unused)))
 {
-    char namebuf[MAX_MAILBOX_NAME+1];
+    char namebuf[MAX_MAILBOX_BUFFER];
     struct find_rock *rock = (struct find_rock *) rockp;
     int r = 0;
     long minmatch;
@@ -2129,7 +2129,7 @@ int mboxlist_findall(struct namespace *namespace __attribute__((unused)),
 		     struct auth_state *auth_state, int (*proc)(), void *rock)
 {
     struct find_rock cbrock;
-    char usermboxname[MAX_MAILBOX_NAME+1];
+    char usermboxname[MAX_MAILBOX_BUFFER];
     int usermboxnamelen = 0;
     const char *data;
     int datalen;
@@ -2137,7 +2137,7 @@ int mboxlist_findall(struct namespace *namespace __attribute__((unused)),
     char *p;
     int prefixlen;
     int userlen = userid ? strlen(userid) : 0, domainlen = 0;
-    char domainpat[MAX_MAILBOX_NAME+1] = ""; /* do intra-domain fetches only */
+    char domainpat[MAX_MAILBOX_BUFFER] = ""; /* do intra-domain fetches only */
     char *pat = NULL;
 
     if (config_virtdomains) {
@@ -2192,7 +2192,7 @@ int mboxlist_findall(struct namespace *namespace __attribute__((unused)),
 
     /* Build usermboxname */
     if (userid && (!(p = strchr(userid, '.')) || ((p - userid) > userlen)) &&
-	strlen(userid)+5 < MAX_MAILBOX_NAME) {
+	strlen(userid)+5 < MAX_MAILBOX_BUFFER) {
 	if (domainlen)
 	    snprintf(usermboxname, sizeof(usermboxname),
 		     "%s!", userid+userlen+1);
@@ -2306,7 +2306,7 @@ int mboxlist_findall_alt(struct namespace *namespace,
 			 void *rock)
 {
     struct find_rock cbrock;
-    char usermboxname[MAX_MAILBOX_NAME+1], patbuf[MAX_MAILBOX_NAME+1];
+    char usermboxname[MAX_MAILBOX_BUFFER], patbuf[MAX_MAILBOX_BUFFER];
     int usermboxnamelen = 0;
     const char *data;
     int datalen;
@@ -2314,7 +2314,7 @@ int mboxlist_findall_alt(struct namespace *namespace,
     char *p;
     int prefixlen, len;
     int userlen = userid ? strlen(userid) : 0, domainlen = 0;
-    char domainpat[MAX_MAILBOX_NAME+1]; /* do intra-domain fetches only */
+    char domainpat[MAX_MAILBOX_BUFFER]; /* do intra-domain fetches only */
     char *pat = NULL;
 
     if (config_virtdomains && userid && (p = strchr(userid, '@'))) {
@@ -2338,7 +2338,7 @@ int mboxlist_findall_alt(struct namespace *namespace,
 
     /* Build usermboxname */
     if (userid && (!(p = strchr(userid, '.')) || ((p - userid) > userlen)) &&
-	strlen(userid)+5 < MAX_MAILBOX_NAME) {
+	strlen(userid)+5 < MAX_MAILBOX_BUFFER) {
 	if (domainlen)
 	    snprintf(usermboxname, sizeof(usermboxname),
 		     "%s!", userid+userlen+1);
@@ -2946,7 +2946,7 @@ int mboxlist_findsub(struct namespace *namespace __attribute__((unused)),
 {
     struct db *subs = NULL;
     struct find_rock cbrock;
-    char usermboxname[MAX_MAILBOX_NAME+1];
+    char usermboxname[MAX_MAILBOX_BUFFER];
     int usermboxnamelen = 0;
     const char *data;
     int datalen;
@@ -2954,7 +2954,7 @@ int mboxlist_findsub(struct namespace *namespace __attribute__((unused)),
     char *p;
     int prefixlen;
     int userlen = userid ? strlen(userid) : 0, domainlen = 0;
-    char domainpat[MAX_MAILBOX_NAME+1]; /* do intra-domain fetches only */
+    char domainpat[MAX_MAILBOX_BUFFER]; /* do intra-domain fetches only */
     char *pat = NULL;
 
     if (config_virtdomains && userid && (p = strchr(userid, '@'))) {
@@ -2984,7 +2984,7 @@ int mboxlist_findsub(struct namespace *namespace __attribute__((unused)),
 
     /* Build usermboxname */
     if (userid && (!(p = strchr(userid, '.')) || ((p - userid) > userlen)) &&
-	strlen(userid)+5 < MAX_MAILBOX_NAME) {
+	strlen(userid)+5 < MAX_MAILBOX_BUFFER) {
 	if (domainlen)
 	    snprintf(usermboxname, sizeof(usermboxname),
 		     "%s!", userid+userlen+1);
@@ -3097,7 +3097,7 @@ int mboxlist_findsub_alt(struct namespace *namespace,
 {
     struct db *subs = NULL;
     struct find_rock cbrock;
-    char usermboxname[MAX_MAILBOX_NAME+1], patbuf[MAX_MAILBOX_NAME+1];
+    char usermboxname[MAX_MAILBOX_BUFFER], patbuf[MAX_MAILBOX_BUFFER];
     int usermboxnamelen = 0;
     const char *data;
     int datalen;
@@ -3105,7 +3105,7 @@ int mboxlist_findsub_alt(struct namespace *namespace,
     char *p;
     int prefixlen, len;
     int userlen = userid ? strlen(userid) : 0, domainlen = 0;
-    char domainpat[MAX_MAILBOX_NAME+1]; /* do intra-domain fetches only */
+    char domainpat[MAX_MAILBOX_BUFFER]; /* do intra-domain fetches only */
     char *pat = NULL;
 
     if (config_virtdomains && userid && (p = strchr(userid, '@'))) {
@@ -3135,7 +3135,7 @@ int mboxlist_findsub_alt(struct namespace *namespace,
 
     /* Build usermboxname */
     if (userid && (!(p = strchr(userid, '.')) || ((p - userid) > userlen)) &&
-	strlen(userid)+5 < MAX_MAILBOX_NAME) {
+	strlen(userid)+5 < MAX_MAILBOX_BUFFER) {
 	if (domainlen)
 	    snprintf(usermboxname, sizeof(usermboxname),
 		     "%s!", userid+userlen+1);
@@ -3311,6 +3311,22 @@ int mboxlist_findsub_alt(struct namespace *namespace,
     return r;
 }
 
+/* returns CYRUSDB_NOTFOUND if the folder doesn't exist, and 0 if it does! */
+int mboxlist_checksub(const char *name, const char *userid)
+{
+    int r;
+    struct db *subs;
+    const char *val;
+    int vallen;
+
+    r = mboxlist_opensubs(userid, &subs);
+
+    if (!r) r = SUBDB->fetch(subs, name, strlen(name), &val, &vallen, NULL);
+
+    mboxlist_closesubs(subs);
+    return r;
+}
+
 /*
  * Change 'user's subscription status for mailbox 'name'.
  * Subscribes if 'add' is nonzero, unsubscribes otherwise.
