@@ -39,7 +39,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: pop3d.c,v 1.187 2008/04/11 20:07:00 murch Exp $
+ * $Id: pop3d.c,v 1.191 2009/02/09 05:01:58 brong Exp $
  */
 
 #include <config.h>
@@ -160,8 +160,8 @@ static struct protocol_t pop3_protocol =
     { { "SASL ", CAPA_AUTH },
       { "STLS", CAPA_STARTTLS },
       { NULL, 0 } } },
-  { "STLS", "+OK", "-ERR" },
-  { "AUTH", 255, 0, "+OK", "-ERR", "+ ", "*", NULL },
+  { "STLS", "+OK", "-ERR", 0 },
+  { "AUTH", 255, 0, "+OK", "-ERR", "+ ", "*", NULL, 0 },
   { "NOOP", NULL, "+OK" },
   { "QUIT", NULL, "+OK" }
 };
@@ -213,7 +213,7 @@ static int popd_canon_user(sasl_conn_t *conn, void *context,
 			   unsigned flags, const char *user_realm,
 			   char *out, unsigned out_max, unsigned *out_ulen)
 {
-    char userbuf[MAX_MAILBOX_NAME+1], *p;
+    char userbuf[MAX_MAILBOX_BUFFER], *p;
     size_t n;
     int r;
 
@@ -221,7 +221,7 @@ static int popd_canon_user(sasl_conn_t *conn, void *context,
 
     if (config_getswitch(IMAPOPT_POPSUBFOLDERS)) {
 	/* make a working copy of the auth[z]id */
-	if (ulen > MAX_MAILBOX_NAME) {
+	if (ulen >= MAX_MAILBOX_BUFFER) {
 	    sasl_seterror(conn, 0, "buffer overflow while canonicalizing");
 	    return SASL_BUFOVER;
 	}
@@ -277,12 +277,12 @@ static int popd_proxy_policy(sasl_conn_t *conn,
 			     struct propctx *propctx)
 {
     if (config_getswitch(IMAPOPT_POPSUBFOLDERS)) {
-	char userbuf[MAX_MAILBOX_NAME+1], *p;
+	char userbuf[MAX_MAILBOX_BUFFER], *p;
 	size_t n;
 
 	/* make a working copy of the authzid */
 	if (!rlen) rlen = strlen(requested_user);
-	if (rlen > MAX_MAILBOX_NAME) {
+	if (rlen >= MAX_MAILBOX_BUFFER) {
 	    sasl_seterror(conn, 0, "buffer overflow while proxying");
 	    return SASL_BUFOVER;
 	}
@@ -551,13 +551,13 @@ int service_main(int argc __attribute__((unused)),
 	syslog(LOG_WARNING, "APOP disabled: can't create challenge");
     }
 
-    prot_printf(popd_out, "+OK %s", popd_apop_chal);
+    prot_printf(popd_out, "+OK");
     if (config_serverinfo) prot_printf(popd_out, " %s", config_servername);
     if (config_serverinfo == IMAP_ENUM_SERVERINFO_ON) {
 	prot_printf(popd_out, " Cyrus POP3%s %s",
 		    config_mupdate_server ? " Murder" : "", CYRUS_VERSION);
     }
-    prot_printf(popd_out, " server ready\r\n");
+    prot_printf(popd_out, " server ready %s\r\n", popd_apop_chal);
 
     cmdloop();
 
@@ -1212,7 +1212,7 @@ static void cmd_apop(char *response)
 
 void cmd_user(char *user)
 {
-    char userbuf[MAX_MAILBOX_NAME+1], *dot, *domain;
+    char userbuf[MAX_MAILBOX_BUFFER], *dot, *domain;
     unsigned userlen;
 
     /* possibly disallow USER */
@@ -1235,7 +1235,7 @@ void cmd_user(char *user)
 	     (popd_namespace.hier_sep == '.' && (dot = strchr(userbuf, '.')) &&
 	      !(config_virtdomains &&  /* allow '.' in dom.ain */
 		(domain = strchr(userbuf, '@')) && (dot > domain))) ||
-	     strlen(userbuf) + 6 > MAX_MAILBOX_NAME) {
+	     strlen(userbuf) + 6 >= MAX_MAILBOX_BUFFER) {
 	prot_printf(popd_out, "-ERR [AUTH] Invalid user\r\n");
 	syslog(LOG_NOTICE,
 	       "badlogin: %s plaintext %s invalid user",
@@ -1359,7 +1359,7 @@ void cmd_capa()
     prot_printf(popd_out, "+OK List of capabilities follows\r\n");
 
     /* SASL special case: print SASL, then a list of supported capabilities */
-    if (!popd_mailbox && !backend &&
+    if ((!popd_authstate || saslprops.ssf) &&
 	sasl_listmech(popd_saslconn,
 		      NULL, /* should be id string */
 		      "SASL ", " ", "\r\n",
@@ -1368,7 +1368,7 @@ void cmd_capa()
 	prot_write(popd_out, mechlist, strlen(mechlist));
     }
 
-    if (tls_enabled() && !popd_starttls_done && !popd_mailbox && !backend) {
+    if (tls_enabled() && !popd_starttls_done && !popd_authstate) {
 	prot_printf(popd_out, "STLS\r\n");
     }
     if (expire < 0) {
@@ -1384,7 +1384,7 @@ void cmd_capa()
     prot_printf(popd_out, "RESP-CODES\r\n");
     prot_printf(popd_out, "AUTH-RESP-CODE\r\n");
 
-    if (!popd_mailbox && !backend &&
+    if (!popd_authstate &&
 	(kflag || popd_starttls_done || (extprops_ssf > 1)
 	 || config_getswitch(IMAPOPT_ALLOWPLAINTEXT))) {
 	prot_printf(popd_out, "USER\r\n");
@@ -1514,7 +1514,7 @@ void cmd_auth(char *arg)
     /* If we're proxying, the authzid may contain a subfolder,
        so re-canonify it */
     if (config_getswitch(IMAPOPT_POPSUBFOLDERS) && strchr(canon_user, '+')) {
-	char userbuf[MAX_MAILBOX_NAME+1];
+	char userbuf[MAX_MAILBOX_BUFFER];
 	unsigned userlen;
 
 	sasl_result = popd_canon_user(popd_saslconn, NULL, canon_user, 0,
@@ -1535,6 +1535,9 @@ void cmd_auth(char *arg)
 	   popd_userid, popd_subfolder ? popd_subfolder : "",
 	   authtype, popd_starttls_done ? "+TLS" : "", "User logged in");
 
+    sasl_getprop(popd_saslconn, SASL_SSF, &val);
+    saslprops.ssf = *((sasl_ssf_t *) val);
+
     if (!openinbox()) {
 	prot_setsasl(popd_in,  popd_saslconn);
 	prot_setsasl(popd_out, popd_saslconn);
@@ -1549,8 +1552,8 @@ void cmd_auth(char *arg)
  */
 int openinbox(void)
 {
-    char userid[MAX_MAILBOX_NAME+1], inboxname[MAX_MAILBOX_PATH+1];
-    char extname[MAX_MAILBOX_NAME+1] = "INBOX";
+    char userid[MAX_MAILBOX_BUFFER], inboxname[MAX_MAILBOX_BUFFER];
+    char extname[MAX_MAILBOX_BUFFER] = "INBOX";
     int type, myrights = 0;
     char *server = NULL, *acl;
     int r, log_level = LOG_ERR;
