@@ -39,7 +39,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: sync_log.h,v 1.3 2008/03/24 17:09:20 murch Exp $
+ * $Id: sync_log.h,v 1.4 2009/01/30 10:54:13 brong Exp $
  *
  * Original version written by David Carter <dpc22@cam.ac.uk>
  * Rewritten and integrated into Cyrus by Ken Murchison <ken@oceana.com>
@@ -81,8 +81,7 @@ void sync_log(char *fmt, ...);
 #define sync_log_seen(user, name) \
     sync_log("SEEN %s %s\n", user, name)
 
-#define sync_log_subscribe(user, name, add) \
-    if (add) sync_log("SUB %s %s\n", user, name); \
-    else sync_log("UNSUB %s %s\n", user, name)
+#define sync_log_subscribe(user, name) \
+    sync_log("SUB %s %s\n", user, name)
 
 #endif /* INCLUDED_SYNC_LOG_H */
