@@ -39,7 +39,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: user.c,v 1.24 2008/03/24 17:09:20 murch Exp $
+ * $Id: user.c,v 1.26 2009/02/09 05:01:59 brong Exp $
  */
 
 #include <config.h>
@@ -91,8 +91,12 @@ static int user_deleteacl(char *name, int matchlen, int maycreate, void* rock)
     int r;
     char *acl;
     char *rights, *nextid;
+    char *origacl, *aclalloc;
 
-    r = mboxlist_lookup(name, &acl, NULL);
+    r = mboxlist_lookup(name, &origacl, NULL);
+
+    /* setacl re-calls mboxlist_lookup and will stomp on us */
+    aclalloc = acl = xstrdup(origacl);
 
     while (!r && acl) {
 	rights = strchr(acl, '\t');
@@ -111,6 +115,9 @@ static int user_deleteacl(char *name, int matchlen, int maycreate, void* rock)
 
 	acl = nextid;
     }
+
+    free(aclalloc);
+
     return 0;
 }
 #endif
@@ -214,7 +221,7 @@ static int user_renamesub(char *name, int matchlen __attribute__((unused)),
 			  int maycreate __attribute__((unused)), void* rock)
 {
     struct rename_rock *rrock = (struct rename_rock *) rock;
-    char newname[MAX_MAILBOX_NAME+1];
+    char newname[MAX_MAILBOX_BUFFER];
 
     if (!strncasecmp(name, "INBOX", 5) &&
 	(name[5] == '\0' || name[5] == '.')) {
@@ -312,10 +319,10 @@ int user_renamedata(char *olduser, char *newuser,
 		    struct auth_state *authstate)
 {
     struct namespace namespace;
-    char oldinbox[MAX_MAILBOX_NAME+1], newinbox[MAX_MAILBOX_NAME+1];
+    char oldinbox[MAX_MAILBOX_BUFFER], newinbox[MAX_MAILBOX_BUFFER];
     char *olddomain, *newdomain;
     struct rename_rock rrock;
-    char pat[MAX_MAILBOX_NAME+1];
+    char pat[MAX_MAILBOX_BUFFER];
     int r;
 
     /* set namespace */
@@ -370,8 +377,12 @@ int user_renameacl(char *name, char *olduser, char *newuser)
     int r = 0;
     char *acl;
     char *rights, *nextid;
+    char *origacl, *aclalloc;
 
-    r = mboxlist_lookup(name, &acl, NULL);
+    r = mboxlist_lookup(name, &origacl, NULL);
+
+    /* setacl re-calls mboxlist_lookup and will stomp on us */
+    aclalloc = acl = xstrdup(origacl);
 
     while (!r && acl) {
 	rights = strchr(acl, '\t');
@@ -393,6 +404,8 @@ int user_renameacl(char *name, char *olduser, char *newuser)
 	acl = nextid;
     }
 
+    free(aclalloc);
+
     return r;
 }
 
@@ -443,7 +456,7 @@ static int find_cb(void *rockp,
 int user_deletequotaroots(const char *user)
 {
     struct namespace namespace;
-    char buf[MAX_MAILBOX_NAME+1], *inboxname = buf;
+    char buf[MAX_MAILBOX_BUFFER], *inboxname = buf;
     struct txn *tid = NULL;
     int r;
 
