@@ -41,7 +41,7 @@
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
  *
- * $Id: imtest.c,v 1.120 2008/10/08 15:47:08 murch Exp $
+ * $Id: imtest.c,v 1.124 2009/01/14 15:50:47 murch Exp $
  */
 
 #include "config.h"
@@ -1867,7 +1867,7 @@ static void *pop3_parse_banner(char *str)
     char *chal = NULL;
     
     /* look for APOP challenge in banner '<...@...>' */
-    cp = str+4;
+    cp = str+3;
     while (cp && (start = strchr(cp, '<'))) {
 	cp = start + 1;
 	while (*cp && *cp != '@' && *cp != '<' && *cp != '>') cp++;
@@ -1905,7 +1905,7 @@ static int auth_pop(void)
     
     printf("S: %s", str);
     
-    if (strncasecmp(str, "+OK ", 4)) return IMTEST_FAIL;
+    if (strncasecmp(str, "+OK", 3)) return IMTEST_FAIL;
     
     interaction(SASL_CB_PASS, NULL, "Please enter your password",
 		&pass, &passlen);
@@ -1920,7 +1920,7 @@ static int auth_pop(void)
     
     printf("S: %s", str);
     
-    if (!strncasecmp(str, "+OK ", 4)) {
+    if (!strncasecmp(str, "+OK", 3)) {
 	return IMTEST_OK;
     } else {
 	return IMTEST_FAIL;
@@ -1968,7 +1968,7 @@ static int auth_apop(char *apop_chal)
     
     printf("S: %s", str);
     
-    if (!strncasecmp(str, "+OK ", 4)) {
+    if (!strncasecmp(str, "+OK", 3)) {
 	return IMTEST_OK;
     } else {
 	return IMTEST_FAIL;
@@ -2233,7 +2233,7 @@ static struct protocol_t protocols[] = {
       &imap_init_conn, &generic_pipe, &imap_reset
     },
     { "pop3", "pop3s", "pop",
-      { 0, "+OK ", &pop3_parse_banner },
+      { 0, "+OK", &pop3_parse_banner },
       { "CAPA", ".", "STLS", "SASL ", NULL },
       { "STLS", "+OK", "-ERR", 0 },
       { "AUTH", 255, 0, "+OK", "-ERR", "+ ", "*", NULL, 0 },
@@ -2524,6 +2524,12 @@ int main(int argc, char **argv)
 	    
 	    prot_free(pin);
 	    prot_free(pout);
+
+	    /* Properly shutdown TLS so that session can be reused */
+	    if (tls_conn) {
+		SSL_shutdown(tls_conn);
+		SSL_set_shutdown(tls_conn, SSL_SENT_SHUTDOWN|SSL_RECEIVED_SHUTDOWN);
+	    }
 	    
 	    close(sock);
 	    
@@ -2624,7 +2630,6 @@ int main(int argc, char **argv)
 	}
 	
 	if (rock) free(rock);
-	if (mechlist) free(mechlist);
 	
 	if (result == IMTEST_OK) {
 	    printf("Authenticated.\n");
@@ -2645,15 +2650,41 @@ int main(int argc, char **argv)
 	} else {
 	    printf("Security strength factor: %d\n", ext_ssf + ssf);
 
-	    if (ssf && protocol->sasl_cmd.auto_capa) {
+	    if (ssf) {
 		/* ask for the capabilities again */
+		char *new_mechlist;
+
 		if (verbose==1)
 		    printf("Asking for capabilities again "
 			   "since they might have changed\n");
-		mechlist = ask_capability(protocol, &server_supports_tls, 1);
-		if (mechlist) free(mechlist);
+		if (!strcmp(protocol->protocol, "sieve")) {
+		    /* XXX  Hack to handle ManageSieve servers.
+		     * No way to tell from protocol if server will
+		     * automatically send capabilities, so we treat it
+		     * as optional.
+		     */
+		    char ch;
+
+		    /* wait and probe for possible auto-capability response*/
+		    usleep(250000);
+		    prot_NONBLOCK(pin);
+		    if ((ch = prot_getc(pin)) != EOF) {
+			prot_ungetc(ch, pin);
+		    } else {
+			protocol->sasl_cmd.auto_capa = 0;
+		    }
+		    prot_BLOCK(pin);
+		}
+		new_mechlist = ask_capability(protocol, &server_supports_tls,
+					      protocol->sasl_cmd.auto_capa);
+		if (new_mechlist && strcmp(new_mechlist, mechlist)) {
+		    printf("WARNING: possible MITM attack: "
+			   "list of available SASL mechanisms changed\n");
+		    free(new_mechlist);
+		}
 	    }
 	}
+	if (mechlist) free(mechlist);
 
     } while (--reauth);
 
