@@ -1,19 +1,18 @@
 /*
  * Mar  8, 2000 by Hajimu UMEMOTO <ume@mahoroba.org>
- * $Id: getaddrinfo.c,v 1.3 2002/03/12 18:10:51 ken3 Exp $
  *
  * This module is besed on ssh-1.2.27-IPv6-1.5 written by
  * KIKUCHI Takahiro <kick@kyoto.wide.ad.jp>
  */
-/* 
- * Copyright (c) 2001 Carnegie Mellon University.  All rights reserved.
+/*
+ * Copyright (c) 1994-2008 Carnegie Mellon University.  All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
  *
  * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer. 
+ *    notice, this list of conditions and the following disclaimer.
  *
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in
@@ -22,14 +21,15 @@
  *
  * 3. The name "Carnegie Mellon University" must not be used to
  *    endorse or promote products derived from this software without
- *    prior written permission. For permission or any other legal
- *    details, please contact  
- *      Office of Technology Transfer
+ *    prior written permission. For permission or any legal
+ *    details, please contact
  *      Carnegie Mellon University
- *      5000 Forbes Avenue
- *      Pittsburgh, PA  15213-3890
- *      (412) 268-4387, fax: (412) 268-7395
- *      tech-transfer@andrew.cmu.edu
+ *      Center for Technology Transfer and Enterprise Creation
+ *      4615 Forbes Avenue
+ *      Suite 302
+ *      Pittsburgh, PA  15213
+ *      (412) 268-7393, fax: (412) 268-7395
+ *      innovation@andrew.cmu.edu
  *
  * 4. Redistributions of any form whatsoever must retain the following
  *    acknowledgment:
@@ -43,6 +43,8 @@
  * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
  * AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING
  * OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+ *
+ * $Id: getaddrinfo.c,v 1.7 2008/03/24 17:43:08 murch Exp $
  */
 /*
  * fake library for ssh
@@ -97,12 +99,12 @@ char *
 gai_strerror(int ecode)
 {
     switch (ecode) {
-    case EAI_NODATA:
-	return "no address associated with hostname.";
     case EAI_MEMORY:
 	return "memory allocation failure.";
     case EAI_FAMILY:
 	return "ai_family not supported.";
+    case EAI_NONAME:
+	return "hostname nor servname provided, or not known.";
     case EAI_SERVICE:
 	return "servname not supported for ai_socktype.";
     default:
@@ -193,7 +195,7 @@ getaddrinfo(const char *hostname, const char *servname,
 	    return EAI_MEMORY;
     }
     if (hints && hints->ai_flags & AI_NUMERICHOST)
-	return EAI_NODATA;
+	return EAI_NONAME;
 #ifndef macintosh
     if ((hp = gethostbyname(hostname)) &&
 	hp->h_name && hp->h_name[0] && hp->h_addr_list[0]) {
@@ -221,5 +223,5 @@ getaddrinfo(const char *hostname, const char *servname,
 	return 0;
     }
 #endif
-    return EAI_NODATA;
+    return EAI_NONAME;
 }
